@@ -142,7 +142,13 @@ class Template(collections.Mapping):
         def handle_getatt(args):
             resource, att = args
             try:
-                return resources[resource].FnGetAtt(att)
+                r = resources[resource]
+                if r.state in (
+                        r.CREATE_IN_PROGRESS,
+                        r.CREATE_COMPLETE,
+                        r.UPDATE_IN_PROGRESS,
+                        r.UPDATE_COMPLETE):
+                    return r.FnGetAtt(att)
             except KeyError:
                 raise exception.InvalidTemplateAttribute(resource=resource,
                                                          key=att)
@@ -205,7 +211,14 @@ class Template(collections.Mapping):
 
             if not isinstance(strings, (list, tuple)):
                 raise TypeError('Arguments to "Fn::Join" not fully resolved')
-            return delim.join(strings)
+
+            def empty_for_none(v):
+                if v is None:
+                    return ''
+                else:
+                    return v
+
+            return delim.join(empty_for_none(value) for value in strings)
 
         return _resolve(lambda k, v: k == 'Fn::Join', handle_join, s)
 
